@@ -1,7 +1,8 @@
 #!/bin/sh
+export PATH='/usr/obj/hs-mtl-2.1.3.1/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: mtl
-version: 2.1.2
-id: mtl-2.1.2-02e701f9b1590ee88a0b5b0bd5d93a29
+version: 2.1.3.1
+id: mtl-2.1.3.1-96f1a7910a7553352339ed05fb61c269
 
 license: BSD3
 copyright:
@@ -31,20 +32,20 @@ exposed-modules: Control.Monad.Cont Control.Monad.Cont.Class
                  Control.Monad.Writer.Strict
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/mtl-2.1.2
-library-dirs: /usr/local/lib/ghc/mtl-2.1.2
-hs-libraries: HSmtl-2.1.2
+import-dirs: /usr/local/lib/ghc/mtl-2.1.3.1
+library-dirs: /usr/local/lib/ghc/mtl-2.1.3.1
+hs-libraries: HSmtl-2.1.3.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
-         transformers-0.3.0.0-8e66ecc7d4dae2b07b2b5406908c70e4
+depends: base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
+         transformers-0.3.0.0-6458c21515cab7c1cf21e53141557a1c
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-mtl-2.1.2/html/mtl.haddock
-haddock-html: /usr/local/share/doc/hs-mtl-2.1.2/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-mtl-2.1.3.1/html/mtl.haddock
+haddock-html: /usr/local/share/doc/hs-mtl-2.1.3.1/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
